| Title: | The Folded t Family of Distributions |
|---|---|
| Description: | Maximum likelihood estimation of the folded t and related distributions. The reference paper is: Psarakis and Panaretos (1990). "The folded t distribution". Communications in Statistics--Theory and Methods, 19(7): 2717--2734. <doi:10.1080/03610929008830342>. |
| Authors: | Michail Tsagris [aut, cre] |
| Maintainer: | Michail Tsagris <[email protected]> |
| License: | GPL (>= 2) |
| Version: | 1.0 |
| Built: | 2026-05-20 09:39:51 UTC |
| Source: | https://github.com/cran/foldedt |
Maximum likelihood estimation of the folded t and related distributions. Probability and density functions, and random generation are also included.
| Package: | foldedt | |
| Type: | Package | |
| Version: | 1.0 | |
| Date: | 2026-03-18 | |
| License: | GPL-2 |
Michail Tsagris [email protected].
Michail Tsagris [email protected].
Psarakis and Panaretos (1990). The folded t distribution. Communications in Statistics–Theory and Methods, 19(7): 2717–2734.
Density function of the (non-standardized) folded t distribution.
dfoldedt(y, mu, s2, v, logged = FALSE)dfoldedt(y, mu, s2, v, logged = FALSE)
y |
A vector with positive values. |
mu |
The location parameter, |
s2 |
The |
v |
The degrees of freedom, |
logged |
If you want the logarithm of the density set this equal to TRUE. |
A vector with the (logged) density function values.
Michail Tsagris.
R implementation and documentation: Michail Tsagris [email protected].
Psarakis and Panaretos (1990). The folded t distribution. Communications in Statistics–Theory and Methods, 19(7): 2717–2734.
https://en.wikipedia.org/wiki/Folded-t_and_half-t_distributions
y <- abs( rt(10, 10, 3) ) dfoldedt(y, mu = 3, s2 = 1, v = 10)y <- abs( rt(10, 10, 3) ) dfoldedt(y, mu = 3, s2 = 1, v = 10)
MLE of the folded t distribution.
foldedt.mle(x)foldedt.mle(x)
x |
A numerical vector with positive real numbers. |
A list including:
param |
The estimated location and scatter parameters, and the degrees of freedom of the folded t distribution. |
loglik |
The value of the maximised log-likelihood. |
Michail Tsagris.
R implementation and documentation: Michail Tsagris [email protected].
Psarakis and Panaretos (1990). The folded t distribution. Communications in Statistics–Theory and Methods, 19(7): 2717–2734.
https://en.wikipedia.org/wiki/Folded-t_and_half-t_distributions
halft.mle, halft1.mle, dfoldedt
x <- abs( rt(1000, 5, 2) ) foldedt.mle(x)x <- abs( rt(1000, 5, 2) ) foldedt.mle(x)
MLE of the half t distribution.
halft.mle(x)halft.mle(x)
x |
A numerical vector with positive real numbers. |
The half-t distribution with degrees of freedom and scatter parameter
has density:
A list including:
param |
The estimated degrees of freedom and the scatter parameter of the half t distribution. |
loglik |
The value of the maximised log-likelihood. |
Michail Tsagris.
R implementation and documentation: Michail Tsagris [email protected].
Psarakis and Panaretos (1990). The folded t distribution. Communications in Statistics–Theory and Methods, 19(7): 2717–2734.
https://en.wikipedia.org/wiki/Folded-t_and_half-t_distributions
x <- abs( rt(1000, 5) ) halft.mle(x)x <- abs( rt(1000, 5) ) halft.mle(x)
MLE of the half t distribution with unit scatter parameter.
halft1.mle(x, tol = 1e-07)halft1.mle(x, tol = 1e-07)
x |
A numerical vector with positive real numbers. |
tol |
The tolerance level up to which the maximisation stops set to 1e-07 by default. |
The half-t distribution with degrees of freedom, zero location parameter and unit scatter parameter has density:
A list including:
iters |
The number of iterations required by the Newton-Raphson algorithm. |
nu |
The estimated degrees of freedom of the half t distribution. |
loglik |
The value of the maximised log-likelihood. |
Michail Tsagris.
R implementation and documentation: Michail Tsagris [email protected].
Psarakis and Panaretos (1990). The folded t distribution. Communications in Statistics–Theory and Methods, 19(7): 2717–2734.
https://en.wikipedia.org/wiki/Folded-t_and_half-t_distributions
x <- abs( rt(1000, 5) ) halft.mle(x)x <- abs( rt(1000, 5) ) halft.mle(x)